*+====================================================================
*+
*+    Source Module => E:\MULTI\BLANKMSG.PRG
*+
*+    Released to Public Domain.
*+
*+    Functions: Function BlankMsg()
*+
*+    Reformatted by Click! 1.10 on Aug-13-1997 at 11:39 pm
*+
*+====================================================================

/* File.....: blankmsg.prg
 * Author...: Peter Townsend
 * CIS ID...:
 * e-mail...: cephas@tpgi.com.au
 *
 * A screensaver.
 */
/*
 * This is an original work by Peter Townsend and is
 * hereby placed in the public domain.
 */
#include "SETCURS.CH"
#include "COMMON.CH"
* ========================================================================= *
/*  $DOC$
 *  $FUNCNAME$
 *      BLANKMSG()
 *
 *  $ONELINER$
 *      A screen saver which displays a screen traversing string.  
 *
 *  $SYNTAX$
 *      BLANKMSG( [<cDisplayString>] )
 *
 *  $ARGUMENTS$
 *      cDisplayString    - the string which is displayed in successive
 *                          locations on the screen.
 *                          Default: "Screen saver is active - press any key"
 *
 *  $RETURNS$
 *      NIL
 *
 *  $DESCRIPTION$
 *      A screen saver which displays a screen traversing string after
 *      blanking out the screen.  When the user presses any key, the
 *      screen is returned to its former state.
 *
 *  $EXAMPLES$
 *      nKey       := INKEY()
 *      nStartTime := SECONDS()
 *      DO WHILE ( nKey == 0 )
 *          IF nStartTime < SECONDS()
 *              nStartTime -= ( 60 * 60 * 24 )
 *          ENDIF
 *          IF ( SECONDS() - nStartTime ) > 120     // 2 minutes
 *              BlankMsg()
 *              nStartTime := SECONDS()
 *          ENDIF
 *          nKey := INKEY()
 *      ENDDO
 *
 *  $SEEALSO$
 *
 *  $INCLUDE$
 *      common.ch
 *      setcurs.ch
 *
 *  $END$
 */

*+--------------------------------------------------------------------
*+
*+    Function BlankMsg()
*+
*+--------------------------------------------------------------------
*+
function BlankMsg( cBlankMsg )

local nMsgRow  := 0
local nMsgCol  := 0
local nMsgLen  := 0
local cMsgNxt  := ""
local lPressed := .F.
local nNxtRow  := 0
local cMsgClr  := "W/N"
local nPrvRow  := 0
local nPrvCol  := 0
local cSaveScr := savescreen( 0, 0, maxrow(), maxcol() )
local nSaveCrs := setcursor( SC_NONE )
local nSaveCol := col()
local nSaveRow := row()
*
DEFAULT cBlankMsg to "Screen saver active - press any key"
nMsgLen := len( cBlankMsg )
* Blank the screen ...
dispbox( 0, 0, maxrow(), maxcol(), space( 9 ), "N/N" )
* ... then wait for a keystroke which is to be discarded.
lPressed := ( inkey() != 0 )
do while ( !lPressed )
   nPrvRow := nMsgRow
   nPrvCol := nMsgCol
   nMsgCol ++
   * Have we hit the R/H side of the screen?
   if ( nMsgCol > maxcol() )
      nMsgCol := 0
      nMsgRow ++
      * Have we hit the bottom of the screen?
      if ( nMsgRow > maxrow() )
         nMsgRow := 0
      endif
   endif
   * Should the message break across a row?
   nNxtRow := - 1
   if ( ( nMsgCol + nMsgLen ) > maxcol() )
      nNxtRow := nMsgRow + 1
      if ( nNxtRow > maxrow() )
         nNxtRow := 0
      endif
      cMsgNxt := substr( cBlankMsg, maxcol() - nMsgCol + 1 )
   endif
   @ nPrvRow, nPrvCol say " "       color cMsgClr        
   @ nMsgRow, nMsgCol say cBlankMsg color cMsgClr        
   if ( nNxtRow > - 1 )
      @ nNxtRow,  0 say cMsgNxt color cMsgClr        
   endif
   lPressed := ( inkey( 0.2 ) != 0 )
enddo
* The user lPressed a key so restore the screen.
restscreen( 0, 0, maxrow(), maxcol(), cSaveScr )
setcursor( nSaveCrs )
setpos( nSaveRow, nSaveCol )
return ( NIL )

*+ EOF: BLANKMSG.PRG
